YMP - a flexible omics pipeline
===============================

Welcome to the YMP documentation! YMP is an omics pipeline designed to be simple to
install and use, yet flexible enough for you to easily add your own custom processing
steps.

YMP is built on top of Snakemake_ and Bioconda_, which are used for task management
and software provisioning, respectively. Around these, YMP provides a simple command
line interface, a dataset configuration management layer and a predefined collection
of rules covering the common tasks for NGS sequence data preprocessing, assembly and
mapping.

.. _Snakemake: https://snakemake.readthedocs.io
.. _Bioconda: https://bioconda.github.io


